                       <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Subject Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="listTable" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th style="width:150px">Code</th>
                                        <th>Subject Name</th>
                                        <th>University Subject Code</th>
                                        <th style="width:50px">Status</th>
                                        <th style="width:100px"></th>
                                    </tr>
                                </thead>                                     
                                <tbody id="tbl_content"> <tr>
                                    <td colspan='5'>
                                            <?php echo loadingText("Loading Subject Names");?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Subject Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
            <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                <div class="row">
                    <span id="ErrCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6"></div>
                    <div class="col-6">
                        <label class="form-label">University Subject Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="UniversitySubjectCode" name="UniversitySubjectCode" placeholder="University Subject Code" value="" onkeypress="clearInput('UniversitySubjectCode')">
                        <span id="ErrUniversitySubjectCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Subject Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SubjectName" id="SubjectName" placeholder="Subject Name" onkeypress="clearInput('SubjectName')">
                        <span id="ErrSubjectName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </form>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Subject Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
            <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
                <input type="hidden" name="ID" id="editID">
                <div class="row">
                    <span id="ErreditCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label>
                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6"></div>
                    <div class="col-6">
                        <label class="form-label">University Subject Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editUniversitySubjectCode" name="UniversitySubjectCode" placeholder="University Subject Code" value="" onkeypress="clearInput('editUniversitySubjectCode')">
                        <span id="ErreditUniversitySubjectCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Subject Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SubjectName" id="editSubjectName" placeholder="Subject Name" value="" onkeypress="clearInput('editSubjectName')">
                        <span id="ErreditSubjectName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1">Active</option>
                            <option value="0">Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </form>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Subject Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                   <div class="col-sm-12">
                        <div style="font-weight: bold;">Code</div>
                        <div id="viewCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">University Subject Code</div>
                        <div id="viewUniversitySubjectCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Subject Name</div>
                        <div id="viewSubjectName"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <div id="viewRemarks"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <div id="viewStatus"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <div id="viewCreatedOn"></div>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
function list() {
      $('#Success').modal("hide");
    $.post(URL+ "webservice.php?action=l&method=masul","",function(data){
      var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            i=0;
            $.each(obj.data, function (index, data) {
                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                            + '<td>' + data.Code + '</td>'
                            + '<td>' + data.SubjectName + '</td>'
                            + '<td>' + data.UniversitySubjectCode + '</td>' 
                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
                             + '<td style="text-align:right">' 
                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'masul\',\''+data.SubjectName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                               + '</td>'
                             + '</tr>' 
                      + '</tr>';
                      i++;
            });
            if(obj.data.length==0){
            html += '<tr>'
                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
                + '</tr>'
            }   
            $('#tbl_content').html(html);
        } else {
             $('#popupcontent').html( error(obj.message));
        }  
    });
}

setTimeout("list()",2000);

function addform(){
         $('#confirmationtoadd').modal("show"); 
         $('#Code').val(""); 
         $('#UniversitySubjectCode').val(""); 
         $('#SubjectName').val(""); 
         $('#Remarks').val(""); 
         
         $('#ErrCode').html("");
         $('#ErrUniversitySubjectCode').html(""); 
         $('#ErrSubjectName').html(""); 
         $('#ErrRemarks').html("");
     
         $("#Code").removeClass("highlight_error"); 
         $("#UniversitySubjectCode").removeClass("highlight_error"); 
         $("#SubjectName").removeClass("highlight_error"); 
         $("#Remarks").removeClass("highlight_error"); 
}

function add(){
    var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
            $("#Code").addClass("highlight_error"); 
           error++;
    }  else {
          $("#Code").removeClass("highlight_error"); 
            $('#ErrCode').html(""); 
    } 
    if ($('#UniversitySubjectCode').val()==""){
            $('#ErrUniversitySubjectCode').html("Please enter University Subject Code");
          $("#UniversitySubjectCode").addClass("highlight_error"); 
           error++;
    }  else {
         $("#UniversitySubjectCode").removeClass("highlight_error"); 
            $('#ErrUniversitySubjectCode').html(""); 
    }
    if ($('#SubjectName').val()==""){
            $('#ErrSubjectName').html("Please enter Subject Name");
            $("#SubjectName").addClass("highlight_error"); 
            error++;
    }  else {
            $("#SubjectName").removeClass("highlight_error"); 
            $('#ErrSubjectName').html(""); 
    } 
    if(error==0){
        var param = $('#frm_create').serialize();
        $.post(URL+"webservice.php?action=a&method=masul",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoadd').modal("hide"); 
             $('#Success').modal("show");    
        }   else {
            $('#ErrCommon').html(print_inlineError(obj.message));
        }
    });
   } 
   
}

function editform(ID){
     $('#confirmationtoedit').modal("show"); 
     
     $('#ErreditCode').html("");
     $('#ErreditUniversitySubjectCode').html(""); 
     $('#ErreditSubjectName').html(""); 
     $('#ErreditRemarks').html("");
         
      $("#editCode").removeClass("highlight_error"); 
      $("#editUniversitySubjectCode").removeClass("highlight_error"); 
      $("#editSubjectName").removeClass("highlight_error"); 
      $("#editRemarks").removeClass("highlight_error");
       $.post(URL+ "webservice.php?action=g&method=masul&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            $.each(obj.data, function (index, data) {
                $('#editCode').val(data.Code);
                $('#editUniversitySubjectCode').val(data.UniversitySubjectCode);
                $('#editID').val(data.ID);
                $('#editSubjectName').val(data.SubjectName);
                $('#editStatus').val(data.Status);
                $('#editRemarks').val(data.Remarks);
            });   
}  
        else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
  });
}

function edit(ID){
    var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
          $("#editCode").addClass("highlight_error"); 
           error++;
    }  else {
        $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
    if ($('#editUniversitySubjectCode').val()==""){
            $('#ErreditUniversitySubjectCode').html("Please enter University Subject Code");
            $("#editUniversitySubjectCode").addClass("highlight_error"); 
            error++;
    }  else {
            $("#editUniversitySubjectCode").removeClass("highlight_error"); 
            $('#ErreditUniversitySubjectCode').html(""); 
    }
     if ($('#editSubjectName').val()==""){
            $('#ErreditSubjectName').html("Please enter Subject Name");
            $("#editSubjectName").addClass("highlight_error"); 
           error++;
    }  else {
            $("#editSubjectName").removeClass("highlight_error"); 
            $('#ErreditSubjectName').html(""); 
    } 
     if(error==0){
            var param = $('#frm_edit').serialize();
            $.post(URL+"webservice.php?action=u&method=masul",param,function(data){
            var obj = JSON.parse(data); 
            if (obj.status=="success") {
                 $('#confirmationtoedit').modal("hide");
                 $('#Success').modal("show");  
            }   else {
                $('#ErreditCommon').html(print_inlineError(obj.message));
            }
        });
       }
}

function viewform(ID){
     $('#confirmationtoview').modal("show"); 
     $.post(URL+ "webservice.php?action=g&method=masul&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            $.each(obj.data, function (index, data) {
                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                $('#viewUniversitySubjectCode').html(data.UniversitySubjectCode=="" ? "&nbsp;" : data.UniversitySubjectCode);
                $('#viewSubjectName').html(data.SubjectName=="" ? "&nbsp" : data.SubjectName);
                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
               if(data.Status=="1"){
                $('#viewStatus').html("Active");    
               }
               if(data.Status=="0"){
                $('#viewStatus').html("Deactive");    
               }
            });   
}  
  })
}

 
//Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode","UniversitySubjectCode","editUniversitySubjectCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphanumeric Space Dot only correct */ 
var arr = ["SubjectName","editSubjectName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            console.log(e.keyCode);
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [190,32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}  
</script>
    